@@ -43,7 +43,7 @@ var NAVTREE =
       [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
       [ "Class Members", "functions.html", [
         [ "All", "functions.html", "functions_dup" ],
-        [ "Functions", "functions_func.html", null ],
+        [ "Functions", "functions_func.html", "functions_func" ],
         [ "Typedefs", "functions_type.html", null ]
       ] ]
     ] ],
@@ -56,8 +56,8 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"classcl_1_1_image3_d_g_l.html#a21a8fd551430095711413e831cd42ddd",
-"opencl_8hpp.html#ab76105928c721c5a922a4c1aea804e87"
+"classcl_1_1_image3_d.html",
+"namespacecl.html#a43fd451f30944f957126b167b4eb0664"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
