@@ -7,8 +7,8 @@ var NAVTREEINDEX0 =
 "classcl_1_1_buffer.html#a1c82aa24dd8a4d80b698605f60a26d71":[4,0,0,0,7],
 "classcl_1_1_buffer.html#a1fccfb3a50e8082e41444b27caf46176":[5,0,0,2,3],
 "classcl_1_1_buffer.html#a1fccfb3a50e8082e41444b27caf46176":[4,0,0,0,3],
-"classcl_1_1_buffer.html#a25fc923d46ae00bc9c56009a10b65678":[4,0,0,0,9],
 "classcl_1_1_buffer.html#a25fc923d46ae00bc9c56009a10b65678":[5,0,0,2,9],
+"classcl_1_1_buffer.html#a25fc923d46ae00bc9c56009a10b65678":[4,0,0,0,9],
 "classcl_1_1_buffer.html#a476787afe1d27355d15c5bfeb605711d":[5,0,0,2,2],
 "classcl_1_1_buffer.html#a476787afe1d27355d15c5bfeb605711d":[4,0,0,0,2],
 "classcl_1_1_buffer.html#a57889a887c2a3d6ea76126ec966466e2":[4,0,0,0,5],
@@ -17,28 +17,28 @@ var NAVTREEINDEX0 =
 "classcl_1_1_buffer.html#a68c77da266a476c4b4789bd53aa33337":[4,0,0,0,8],
 "classcl_1_1_buffer.html#a7b4092e9d1481249a5111c523372bb19":[4,0,0,0,10],
 "classcl_1_1_buffer.html#a7b4092e9d1481249a5111c523372bb19":[5,0,0,2,10],
-"classcl_1_1_buffer.html#abc21b28608acbd24f76a55c3e820f2b5":[4,0,0,0,6],
 "classcl_1_1_buffer.html#abc21b28608acbd24f76a55c3e820f2b5":[5,0,0,2,6],
-"classcl_1_1_buffer.html#ad823be4fee124b3bc8d190e3c9f34978":[5,0,0,2,0],
+"classcl_1_1_buffer.html#abc21b28608acbd24f76a55c3e820f2b5":[4,0,0,0,6],
 "classcl_1_1_buffer.html#ad823be4fee124b3bc8d190e3c9f34978":[4,0,0,0,0],
-"classcl_1_1_buffer.html#add82bfd12b7e114a0e7addb5775bdde7":[5,0,0,2,1],
+"classcl_1_1_buffer.html#ad823be4fee124b3bc8d190e3c9f34978":[5,0,0,2,0],
 "classcl_1_1_buffer.html#add82bfd12b7e114a0e7addb5775bdde7":[4,0,0,0,1],
-"classcl_1_1_buffer.html#aecfbe2bf97bcd81708f14c6b70478608":[4,0,0,0,4],
+"classcl_1_1_buffer.html#add82bfd12b7e114a0e7addb5775bdde7":[5,0,0,2,1],
 "classcl_1_1_buffer.html#aecfbe2bf97bcd81708f14c6b70478608":[5,0,0,2,4],
+"classcl_1_1_buffer.html#aecfbe2bf97bcd81708f14c6b70478608":[4,0,0,0,4],
 "classcl_1_1_buffer_g_l.html":[5,0,0,3],
 "classcl_1_1_buffer_g_l.html":[4,0,0,1],
 "classcl_1_1_buffer_g_l.html#a01beb07c72623f84b3e329027a18b997":[4,0,0,1,0],
 "classcl_1_1_buffer_g_l.html#a01beb07c72623f84b3e329027a18b997":[5,0,0,3,0],
 "classcl_1_1_buffer_g_l.html#a38e7ca14a7fe0e29258f9a29c581f747":[4,0,0,1,4],
 "classcl_1_1_buffer_g_l.html#a38e7ca14a7fe0e29258f9a29c581f747":[5,0,0,3,4],
-"classcl_1_1_buffer_g_l.html#a77604377be0e356aabfed15f6ea00b31":[4,0,0,1,1],
 "classcl_1_1_buffer_g_l.html#a77604377be0e356aabfed15f6ea00b31":[5,0,0,3,1],
-"classcl_1_1_buffer_g_l.html#ada9b870e058a54ccaf4789e045d1d570":[4,0,0,1,3],
+"classcl_1_1_buffer_g_l.html#a77604377be0e356aabfed15f6ea00b31":[4,0,0,1,1],
 "classcl_1_1_buffer_g_l.html#ada9b870e058a54ccaf4789e045d1d570":[5,0,0,3,3],
-"classcl_1_1_buffer_g_l.html#ae70de3a74671b3a93e05279a8185cd7a":[4,0,0,1,2],
+"classcl_1_1_buffer_g_l.html#ada9b870e058a54ccaf4789e045d1d570":[4,0,0,1,3],
 "classcl_1_1_buffer_g_l.html#ae70de3a74671b3a93e05279a8185cd7a":[5,0,0,3,2],
-"classcl_1_1_buffer_render_g_l.html":[4,0,0,2],
+"classcl_1_1_buffer_g_l.html#ae70de3a74671b3a93e05279a8185cd7a":[4,0,0,1,2],
 "classcl_1_1_buffer_render_g_l.html":[5,0,0,4],
+"classcl_1_1_buffer_render_g_l.html":[4,0,0,2],
 "classcl_1_1_buffer_render_g_l.html#a148deb18e39ee7553a96eb8e56557f5f":[5,0,0,4,3],
 "classcl_1_1_buffer_render_g_l.html#a148deb18e39ee7553a96eb8e56557f5f":[4,0,0,2,3],
 "classcl_1_1_buffer_render_g_l.html#a3214caef962ed7c7ff20e102f498eff6":[4,0,0,2,2],
@@ -47,120 +47,132 @@ var NAVTREEINDEX0 =
 "classcl_1_1_buffer_render_g_l.html#a9ae513ba0c6664353c389764c7e1011d":[4,0,0,2,1],
 "classcl_1_1_buffer_render_g_l.html#ada9141b7a7679f787c41c37fa35cd396":[5,0,0,4,0],
 "classcl_1_1_buffer_render_g_l.html#ada9141b7a7679f787c41c37fa35cd396":[4,0,0,2,0],
-"classcl_1_1_buffer_render_g_l.html#aeb0b208f83304c4b375a844c59ad6785":[5,0,0,4,4],
 "classcl_1_1_buffer_render_g_l.html#aeb0b208f83304c4b375a844c59ad6785":[4,0,0,2,4],
+"classcl_1_1_buffer_render_g_l.html#aeb0b208f83304c4b375a844c59ad6785":[5,0,0,4,4],
 "classcl_1_1_command_queue.html":[4,0,0,3],
 "classcl_1_1_command_queue.html":[5,0,0,5],
-"classcl_1_1_command_queue.html#a098e6374e539f0479a4a4bfe3329321d":[4,0,0,3,21],
-"classcl_1_1_command_queue.html#a098e6374e539f0479a4a4bfe3329321d":[5,0,0,5,21],
+"classcl_1_1_command_queue.html#a025bcbfd09f04d3ebb37c8e0e1efd52c":[5,0,0,5,18],
+"classcl_1_1_command_queue.html#a025bcbfd09f04d3ebb37c8e0e1efd52c":[4,0,0,3,18],
+"classcl_1_1_command_queue.html#a098e6374e539f0479a4a4bfe3329321d":[4,0,0,3,27],
+"classcl_1_1_command_queue.html#a098e6374e539f0479a4a4bfe3329321d":[5,0,0,5,27],
 "classcl_1_1_command_queue.html#a09be675998c51f36aa7744b47eabebd3":[4,0,0,3,6],
 "classcl_1_1_command_queue.html#a09be675998c51f36aa7744b47eabebd3":[5,0,0,5,6],
 "classcl_1_1_command_queue.html#a1b17571eddb31f8b34f232da4c682fe2":[4,0,0,3,4],
 "classcl_1_1_command_queue.html#a1b17571eddb31f8b34f232da4c682fe2":[5,0,0,5,4],
-"classcl_1_1_command_queue.html#a1d7894f5a2eb8d7b30b39f8c0ee680f5":[5,0,0,5,1],
 "classcl_1_1_command_queue.html#a1d7894f5a2eb8d7b30b39f8c0ee680f5":[4,0,0,3,1],
-"classcl_1_1_command_queue.html#a2fecda5e44b7f0872ac9d66cc6d2c907":[5,0,0,5,26],
-"classcl_1_1_command_queue.html#a2fecda5e44b7f0872ac9d66cc6d2c907":[4,0,0,3,26],
-"classcl_1_1_command_queue.html#a3557001a4175126311c658261d2af5cd":[5,0,0,5,19],
-"classcl_1_1_command_queue.html#a3557001a4175126311c658261d2af5cd":[4,0,0,3,19],
-"classcl_1_1_command_queue.html#a500ec329a7dc1c1aee732ab99c4165a4":[5,0,0,5,18],
-"classcl_1_1_command_queue.html#a500ec329a7dc1c1aee732ab99c4165a4":[4,0,0,3,18],
-"classcl_1_1_command_queue.html#a57d5efc58fd858541152c511bf0079e7":[5,0,0,5,5],
+"classcl_1_1_command_queue.html#a1d7894f5a2eb8d7b30b39f8c0ee680f5":[5,0,0,5,1],
+"classcl_1_1_command_queue.html#a2ab3e13bac9bd38d65dd468b72abbfdb":[4,0,0,3,17],
+"classcl_1_1_command_queue.html#a2ab3e13bac9bd38d65dd468b72abbfdb":[5,0,0,5,17],
+"classcl_1_1_command_queue.html#a2fecda5e44b7f0872ac9d66cc6d2c907":[5,0,0,5,32],
+"classcl_1_1_command_queue.html#a2fecda5e44b7f0872ac9d66cc6d2c907":[4,0,0,3,32],
+"classcl_1_1_command_queue.html#a3557001a4175126311c658261d2af5cd":[5,0,0,5,25],
+"classcl_1_1_command_queue.html#a3557001a4175126311c658261d2af5cd":[4,0,0,3,25],
+"classcl_1_1_command_queue.html#a4c4b6d7da2cb0b4fc9c96a14a982b9e0":[4,0,0,3,20],
+"classcl_1_1_command_queue.html#a4c4b6d7da2cb0b4fc9c96a14a982b9e0":[5,0,0,5,20],
+"classcl_1_1_command_queue.html#a500ec329a7dc1c1aee732ab99c4165a4":[4,0,0,3,24],
+"classcl_1_1_command_queue.html#a500ec329a7dc1c1aee732ab99c4165a4":[5,0,0,5,24],
 "classcl_1_1_command_queue.html#a57d5efc58fd858541152c511bf0079e7":[4,0,0,3,5],
-"classcl_1_1_command_queue.html#a5e3a2c54c7dfa2ffe9e7baee7f234dba":[4,0,0,3,0],
+"classcl_1_1_command_queue.html#a57d5efc58fd858541152c511bf0079e7":[5,0,0,5,5],
 "classcl_1_1_command_queue.html#a5e3a2c54c7dfa2ffe9e7baee7f234dba":[5,0,0,5,0],
-"classcl_1_1_command_queue.html#a611e5fa19f23a6a8217505b93aa6c03e":[4,0,0,3,17],
-"classcl_1_1_command_queue.html#a611e5fa19f23a6a8217505b93aa6c03e":[5,0,0,5,17],
+"classcl_1_1_command_queue.html#a5e3a2c54c7dfa2ffe9e7baee7f234dba":[4,0,0,3,0],
+"classcl_1_1_command_queue.html#a60c50201f880973c00bde8be2a948d51":[5,0,0,5,19],
+"classcl_1_1_command_queue.html#a60c50201f880973c00bde8be2a948d51":[4,0,0,3,19],
+"classcl_1_1_command_queue.html#a611e5fa19f23a6a8217505b93aa6c03e":[4,0,0,3,23],
+"classcl_1_1_command_queue.html#a611e5fa19f23a6a8217505b93aa6c03e":[5,0,0,5,23],
 "classcl_1_1_command_queue.html#a637fd03673f1154fe5e33d621d095d01":[5,0,0,5,16],
 "classcl_1_1_command_queue.html#a637fd03673f1154fe5e33d621d095d01":[4,0,0,3,16],
 "classcl_1_1_command_queue.html#a65307d3baf8e319d39103581121cf472":[5,0,0,5,10],
 "classcl_1_1_command_queue.html#a65307d3baf8e319d39103581121cf472":[4,0,0,3,10],
-"classcl_1_1_command_queue.html#a689ad3cb0092077274113b10ff5511d5":[4,0,0,3,22],
-"classcl_1_1_command_queue.html#a689ad3cb0092077274113b10ff5511d5":[5,0,0,5,22],
-"classcl_1_1_command_queue.html#a70660e5b09c93df951583b32d629c639":[5,0,0,5,25],
-"classcl_1_1_command_queue.html#a70660e5b09c93df951583b32d629c639":[4,0,0,3,25],
+"classcl_1_1_command_queue.html#a689ad3cb0092077274113b10ff5511d5":[4,0,0,3,28],
+"classcl_1_1_command_queue.html#a689ad3cb0092077274113b10ff5511d5":[5,0,0,5,28],
+"classcl_1_1_command_queue.html#a70660e5b09c93df951583b32d629c639":[5,0,0,5,31],
+"classcl_1_1_command_queue.html#a70660e5b09c93df951583b32d629c639":[4,0,0,3,31],
 "classcl_1_1_command_queue.html#a71d3d4d029e4e96ffb28d6994aa9a7b0":[5,0,0,5,15],
 "classcl_1_1_command_queue.html#a71d3d4d029e4e96ffb28d6994aa9a7b0":[4,0,0,3,15],
-"classcl_1_1_command_queue.html#a7f5b9cbe7da2d67ea76dfb9408212a55":[5,0,0,5,11],
 "classcl_1_1_command_queue.html#a7f5b9cbe7da2d67ea76dfb9408212a55":[4,0,0,3,11],
+"classcl_1_1_command_queue.html#a7f5b9cbe7da2d67ea76dfb9408212a55":[5,0,0,5,11],
 "classcl_1_1_command_queue.html#a83a98e0487e9307d5815bc171cef5106":[5,0,0,5,3],
 "classcl_1_1_command_queue.html#a83a98e0487e9307d5815bc171cef5106":[4,0,0,3,3],
-"classcl_1_1_command_queue.html#aa958aa4baeff71706ac0e49fa880cbd5":[4,0,0,3,2],
 "classcl_1_1_command_queue.html#aa958aa4baeff71706ac0e49fa880cbd5":[5,0,0,5,2],
+"classcl_1_1_command_queue.html#aa958aa4baeff71706ac0e49fa880cbd5":[4,0,0,3,2],
 "classcl_1_1_command_queue.html#aaa13dc2ededc72ddd46a3634d7ed72c1":[4,0,0,3,14],
 "classcl_1_1_command_queue.html#aaa13dc2ededc72ddd46a3634d7ed72c1":[5,0,0,5,14],
-"classcl_1_1_command_queue.html#aab9fb578bf7cdf13ce831a842a8eb1c0":[4,0,0,3,23],
-"classcl_1_1_command_queue.html#aab9fb578bf7cdf13ce831a842a8eb1c0":[5,0,0,5,23],
+"classcl_1_1_command_queue.html#aab9fb578bf7cdf13ce831a842a8eb1c0":[4,0,0,3,29],
+"classcl_1_1_command_queue.html#aab9fb578bf7cdf13ce831a842a8eb1c0":[5,0,0,5,29],
 "classcl_1_1_command_queue.html#ab25a06cf0df6d38b6516bcc7effb173d":[4,0,0,3,13],
 "classcl_1_1_command_queue.html#ab25a06cf0df6d38b6516bcc7effb173d":[5,0,0,5,13],
+"classcl_1_1_command_queue.html#abda98f0f0e91f7cde238cfb5903e8392":[5,0,0,5,21],
+"classcl_1_1_command_queue.html#abda98f0f0e91f7cde238cfb5903e8392":[4,0,0,3,21],
+"classcl_1_1_command_queue.html#ac5dcc1ac9423e1521dc2685067cba425":[5,0,0,5,22],
+"classcl_1_1_command_queue.html#ac5dcc1ac9423e1521dc2685067cba425":[4,0,0,3,22],
 "classcl_1_1_command_queue.html#acbbbe484d7d6faa84608992b12aedbb8":[4,0,0,3,7],
 "classcl_1_1_command_queue.html#acbbbe484d7d6faa84608992b12aedbb8":[5,0,0,5,7],
-"classcl_1_1_command_queue.html#acfa820d479fbfca9da00ca11f81a423e":[5,0,0,5,8],
 "classcl_1_1_command_queue.html#acfa820d479fbfca9da00ca11f81a423e":[4,0,0,3,8],
+"classcl_1_1_command_queue.html#acfa820d479fbfca9da00ca11f81a423e":[5,0,0,5,8],
 "classcl_1_1_command_queue.html#ad417877c98544115e2a6a76dee22a0a1":[5,0,0,5,9],
 "classcl_1_1_command_queue.html#ad417877c98544115e2a6a76dee22a0a1":[4,0,0,3,9],
-"classcl_1_1_command_queue.html#af667cb0188a581f91bca7ce9edad5f61":[5,0,0,5,24],
-"classcl_1_1_command_queue.html#af667cb0188a581f91bca7ce9edad5f61":[4,0,0,3,24],
-"classcl_1_1_command_queue.html#af9ad6673e3a9f9832f84d89f4d28a951":[4,0,0,3,20],
-"classcl_1_1_command_queue.html#af9ad6673e3a9f9832f84d89f4d28a951":[5,0,0,5,20],
+"classcl_1_1_command_queue.html#af667cb0188a581f91bca7ce9edad5f61":[4,0,0,3,30],
+"classcl_1_1_command_queue.html#af667cb0188a581f91bca7ce9edad5f61":[5,0,0,5,30],
+"classcl_1_1_command_queue.html#af9ad6673e3a9f9832f84d89f4d28a951":[5,0,0,5,26],
+"classcl_1_1_command_queue.html#af9ad6673e3a9f9832f84d89f4d28a951":[4,0,0,3,26],
 "classcl_1_1_command_queue.html#afa0f10bf5cccb3435f2fbfe3d69d44f2":[5,0,0,5,12],
 "classcl_1_1_command_queue.html#afa0f10bf5cccb3435f2fbfe3d69d44f2":[4,0,0,3,12],
-"classcl_1_1_context.html":[4,0,0,4],
 "classcl_1_1_context.html":[5,0,0,6],
-"classcl_1_1_context.html#a026d770523fc9cd9fd668ec206c20066":[4,0,0,4,2],
+"classcl_1_1_context.html":[4,0,0,4],
 "classcl_1_1_context.html#a026d770523fc9cd9fd668ec206c20066":[5,0,0,6,2],
+"classcl_1_1_context.html#a026d770523fc9cd9fd668ec206c20066":[4,0,0,4,2],
 "classcl_1_1_context.html#a03a8dbda2ff24417f199618fc3a90568":[5,0,0,6,8],
 "classcl_1_1_context.html#a03a8dbda2ff24417f199618fc3a90568":[4,0,0,4,8],
-"classcl_1_1_context.html#a0cc4355876b731a5d46821bb0a4abeb1":[4,0,0,4,9],
 "classcl_1_1_context.html#a0cc4355876b731a5d46821bb0a4abeb1":[5,0,0,6,9],
+"classcl_1_1_context.html#a0cc4355876b731a5d46821bb0a4abeb1":[4,0,0,4,9],
 "classcl_1_1_context.html#a3fc0fba33d5b467b5d2ee70adb5b1e92":[5,0,0,6,4],
 "classcl_1_1_context.html#a3fc0fba33d5b467b5d2ee70adb5b1e92":[4,0,0,4,4],
 "classcl_1_1_context.html#a5f00a3ede6edd143bbb2954306290199":[5,0,0,6,7],
 "classcl_1_1_context.html#a5f00a3ede6edd143bbb2954306290199":[4,0,0,4,7],
-"classcl_1_1_context.html#a69ff51d2ac787e171600c63351b48a3a":[4,0,0,4,1],
 "classcl_1_1_context.html#a69ff51d2ac787e171600c63351b48a3a":[5,0,0,6,1],
-"classcl_1_1_context.html#a8f7e1c72445ca6e249bc7a6c9278984d":[5,0,0,6,3],
+"classcl_1_1_context.html#a69ff51d2ac787e171600c63351b48a3a":[4,0,0,4,1],
 "classcl_1_1_context.html#a8f7e1c72445ca6e249bc7a6c9278984d":[4,0,0,4,3],
-"classcl_1_1_context.html#a979d15f9228089af2a657a523b1186e8":[5,0,0,6,5],
+"classcl_1_1_context.html#a8f7e1c72445ca6e249bc7a6c9278984d":[5,0,0,6,3],
 "classcl_1_1_context.html#a979d15f9228089af2a657a523b1186e8":[4,0,0,4,5],
+"classcl_1_1_context.html#a979d15f9228089af2a657a523b1186e8":[5,0,0,6,5],
 "classcl_1_1_context.html#aac7f11aa3129f838fbb15db9b3eee13d":[4,0,0,4,6],
 "classcl_1_1_context.html#aac7f11aa3129f838fbb15db9b3eee13d":[5,0,0,6,6],
 "classcl_1_1_context.html#acaff96595998aeb9db626e3ca3464938":[4,0,0,4,0],
 "classcl_1_1_context.html#acaff96595998aeb9db626e3ca3464938":[5,0,0,6,0],
 "classcl_1_1_device.html":[5,0,0,7],
 "classcl_1_1_device.html":[4,0,0,5],
-"classcl_1_1_device.html#a17c9d32d785f82c74d1abe8793790c1e":[5,0,0,7,6],
 "classcl_1_1_device.html#a17c9d32d785f82c74d1abe8793790c1e":[4,0,0,5,6],
-"classcl_1_1_device.html#a24478e608183c70319367afec954e779":[5,0,0,7,7],
+"classcl_1_1_device.html#a17c9d32d785f82c74d1abe8793790c1e":[5,0,0,7,6],
 "classcl_1_1_device.html#a24478e608183c70319367afec954e779":[4,0,0,5,7],
+"classcl_1_1_device.html#a24478e608183c70319367afec954e779":[5,0,0,7,7],
 "classcl_1_1_device.html#a575493c25049dae087540ed8a65efd6d":[4,0,0,5,5],
 "classcl_1_1_device.html#a575493c25049dae087540ed8a65efd6d":[5,0,0,7,5],
 "classcl_1_1_device.html#a6131ff3eb77c31dfba11091a3c0f4235":[4,0,0,5,0],
 "classcl_1_1_device.html#a6131ff3eb77c31dfba11091a3c0f4235":[5,0,0,7,0],
-"classcl_1_1_device.html#a61b9be541cdcbfd9d4d9f5b0a946a9ed":[4,0,0,5,4],
 "classcl_1_1_device.html#a61b9be541cdcbfd9d4d9f5b0a946a9ed":[5,0,0,7,4],
+"classcl_1_1_device.html#a61b9be541cdcbfd9d4d9f5b0a946a9ed":[4,0,0,5,4],
 "classcl_1_1_device.html#aaff2a95751ef5b9fb3e2604f9f31f837":[4,0,0,5,3],
 "classcl_1_1_device.html#aaff2a95751ef5b9fb3e2604f9f31f837":[5,0,0,7,3],
-"classcl_1_1_device.html#ab60bfd190bf8f82cb8f0adb0a869a2f2":[5,0,0,7,2],
 "classcl_1_1_device.html#ab60bfd190bf8f82cb8f0adb0a869a2f2":[4,0,0,5,2],
-"classcl_1_1_device.html#ad28b573c8a28028a06ded4e1dc7fa725":[5,0,0,7,1],
+"classcl_1_1_device.html#ab60bfd190bf8f82cb8f0adb0a869a2f2":[5,0,0,7,2],
 "classcl_1_1_device.html#ad28b573c8a28028a06ded4e1dc7fa725":[4,0,0,5,1],
-"classcl_1_1_device_command_queue.html":[4,0,0,6],
+"classcl_1_1_device.html#ad28b573c8a28028a06ded4e1dc7fa725":[5,0,0,7,1],
 "classcl_1_1_device_command_queue.html":[5,0,0,8],
+"classcl_1_1_device_command_queue.html":[4,0,0,6],
 "classcl_1_1_device_command_queue.html#a08b305e586841b172422c970a8a461fd":[4,0,0,6,1],
 "classcl_1_1_device_command_queue.html#a08b305e586841b172422c970a8a461fd":[5,0,0,8,1],
 "classcl_1_1_device_command_queue.html#a7daff9dc5967391acf39263e7405041d":[4,0,0,6,2],
 "classcl_1_1_device_command_queue.html#a7daff9dc5967391acf39263e7405041d":[5,0,0,8,2],
-"classcl_1_1_device_command_queue.html#ab58e477e1a9bf099e1faf77565e80856":[5,0,0,8,0],
 "classcl_1_1_device_command_queue.html#ab58e477e1a9bf099e1faf77565e80856":[4,0,0,6,0],
-"classcl_1_1_device_command_queue.html#acaf1dee2f55faeac05b2c1c66daf51c2":[5,0,0,8,4],
+"classcl_1_1_device_command_queue.html#ab58e477e1a9bf099e1faf77565e80856":[5,0,0,8,0],
 "classcl_1_1_device_command_queue.html#acaf1dee2f55faeac05b2c1c66daf51c2":[4,0,0,6,4],
-"classcl_1_1_device_command_queue.html#aed9fbf739ea68dc9826ccf970541e311":[4,0,0,6,3],
+"classcl_1_1_device_command_queue.html#acaf1dee2f55faeac05b2c1c66daf51c2":[5,0,0,8,4],
 "classcl_1_1_device_command_queue.html#aed9fbf739ea68dc9826ccf970541e311":[5,0,0,8,3],
-"classcl_1_1_enqueue_args.html":[5,0,0,9],
+"classcl_1_1_device_command_queue.html#aed9fbf739ea68dc9826ccf970541e311":[4,0,0,6,3],
 "classcl_1_1_enqueue_args.html":[4,0,0,7],
-"classcl_1_1_event.html":[4,0,0,8],
+"classcl_1_1_enqueue_args.html":[5,0,0,9],
 "classcl_1_1_event.html":[5,0,0,10],
+"classcl_1_1_event.html":[4,0,0,8],
 "classcl_1_1_event.html#a01d4e356e0438cd435acce434927a4f3":[4,0,0,8,4],
 "classcl_1_1_event.html#a01d4e356e0438cd435acce434927a4f3":[5,0,0,10,4],
 "classcl_1_1_event.html#a1d548eeb5d4f98d79e3645173f3589c6":[4,0,0,8,7],
@@ -171,8 +183,8 @@ var NAVTREEINDEX0 =
 "classcl_1_1_event.html#a3f5ef317602809c4a99d6f244f758b5f":[4,0,0,8,5],
 "classcl_1_1_event.html#a4ad1d3040fcb24188f1ac2cd73591252":[5,0,0,10,2],
 "classcl_1_1_event.html#a4ad1d3040fcb24188f1ac2cd73591252":[4,0,0,8,2],
-"classcl_1_1_event.html#a51f83064c2024df649667071e81fb847":[4,0,0,8,8],
 "classcl_1_1_event.html#a51f83064c2024df649667071e81fb847":[5,0,0,10,8],
+"classcl_1_1_event.html#a51f83064c2024df649667071e81fb847":[4,0,0,8,8],
 "classcl_1_1_event.html#a90e01689f7b394fc003d66c48a7f6f95":[5,0,0,10,0],
 "classcl_1_1_event.html#a90e01689f7b394fc003d66c48a7f6f95":[4,0,0,8,0],
 "classcl_1_1_event.html#abb50980a18eae852375f7d328d46d3cd":[5,0,0,10,6],
@@ -183,71 +195,59 @@ var NAVTREEINDEX0 =
 "classcl_1_1_image.html":[5,0,0,11],
 "classcl_1_1_image.html#a0f776d3f1103d59864ca46d984d2801f":[4,0,0,9,3],
 "classcl_1_1_image.html#a0f776d3f1103d59864ca46d984d2801f":[5,0,0,11,3],
-"classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9":[5,0,0,11,1],
 "classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9":[4,0,0,9,1],
-"classcl_1_1_image.html#a7bf98f36e2e0bd8627377cfdfc260259":[5,0,0,11,2],
+"classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9":[5,0,0,11,1],
 "classcl_1_1_image.html#a7bf98f36e2e0bd8627377cfdfc260259":[4,0,0,9,2],
+"classcl_1_1_image.html#a7bf98f36e2e0bd8627377cfdfc260259":[5,0,0,11,2],
 "classcl_1_1_image.html#a7eefbcc63b46d4a469afd8822c4204c1":[4,0,0,9,4],
 "classcl_1_1_image.html#a7eefbcc63b46d4a469afd8822c4204c1":[5,0,0,11,4],
 "classcl_1_1_image.html#ad9a2f4b6a5ccbb7056613946bc6ee0b7":[5,0,0,11,0],
 "classcl_1_1_image.html#ad9a2f4b6a5ccbb7056613946bc6ee0b7":[4,0,0,9,0],
-"classcl_1_1_image1_d.html":[4,0,0,10],
 "classcl_1_1_image1_d.html":[5,0,0,12],
+"classcl_1_1_image1_d.html":[4,0,0,10],
 "classcl_1_1_image1_d.html#a0d7c48026af3f726ce861716b6dbe817":[4,0,0,10,1],
 "classcl_1_1_image1_d.html#a0d7c48026af3f726ce861716b6dbe817":[5,0,0,12,1],
-"classcl_1_1_image1_d.html#a339c7f19e331da51595ee14eb4e0b145":[4,0,0,10,3],
 "classcl_1_1_image1_d.html#a339c7f19e331da51595ee14eb4e0b145":[5,0,0,12,3],
-"classcl_1_1_image1_d.html#a35633b9aa0bb3f2c23e48aa8fe3f7a9a":[4,0,0,10,0],
+"classcl_1_1_image1_d.html#a339c7f19e331da51595ee14eb4e0b145":[4,0,0,10,3],
 "classcl_1_1_image1_d.html#a35633b9aa0bb3f2c23e48aa8fe3f7a9a":[5,0,0,12,0],
+"classcl_1_1_image1_d.html#a35633b9aa0bb3f2c23e48aa8fe3f7a9a":[4,0,0,10,0],
 "classcl_1_1_image1_d.html#a7c8b730eba37624cb6d3af30f8a1c276":[5,0,0,12,2],
 "classcl_1_1_image1_d.html#a7c8b730eba37624cb6d3af30f8a1c276":[4,0,0,10,2],
-"classcl_1_1_image1_d_array.html":[4,0,0,11],
 "classcl_1_1_image1_d_array.html":[5,0,0,13],
+"classcl_1_1_image1_d_array.html":[4,0,0,11],
 "classcl_1_1_image1_d_array.html#ae8738615a72593ca2ec82c20d736da03":[4,0,0,11,0],
 "classcl_1_1_image1_d_array.html#ae8738615a72593ca2ec82c20d736da03":[5,0,0,13,0],
-"classcl_1_1_image1_d_buffer.html":[4,0,0,12],
 "classcl_1_1_image1_d_buffer.html":[5,0,0,14],
-"classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088":[5,0,0,14,0],
+"classcl_1_1_image1_d_buffer.html":[4,0,0,12],
 "classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088":[4,0,0,12,0],
-"classcl_1_1_image2_d.html":[4,0,0,13],
+"classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088":[5,0,0,14,0],
 "classcl_1_1_image2_d.html":[5,0,0,15],
+"classcl_1_1_image2_d.html":[4,0,0,13],
 "classcl_1_1_image2_d.html#a2a8221a4c64c1aaf47468c4ef6c05a61":[5,0,0,15,4],
 "classcl_1_1_image2_d.html#a2a8221a4c64c1aaf47468c4ef6c05a61":[4,0,0,13,4],
-"classcl_1_1_image2_d.html#a2ca2508bd1029e23f9f0c673a27398c0":[5,0,0,15,0],
 "classcl_1_1_image2_d.html#a2ca2508bd1029e23f9f0c673a27398c0":[4,0,0,13,0],
+"classcl_1_1_image2_d.html#a2ca2508bd1029e23f9f0c673a27398c0":[5,0,0,15,0],
 "classcl_1_1_image2_d.html#a6ef2c932d8846c4ad7205c5352df687a":[5,0,0,15,3],
 "classcl_1_1_image2_d.html#a6ef2c932d8846c4ad7205c5352df687a":[4,0,0,13,3],
 "classcl_1_1_image2_d.html#a9e7a068876d97b608706d26d1715226e":[5,0,0,15,5],
 "classcl_1_1_image2_d.html#a9e7a068876d97b608706d26d1715226e":[4,0,0,13,5],
-"classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e":[5,0,0,15,1],
 "classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e":[4,0,0,13,1],
-"classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400":[5,0,0,15,2],
+"classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e":[5,0,0,15,1],
 "classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400":[4,0,0,13,2],
+"classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400":[5,0,0,15,2],
 "classcl_1_1_image2_d_array.html":[5,0,0,16],
 "classcl_1_1_image2_d_array.html":[4,0,0,14],
 "classcl_1_1_image2_d_array.html#a8c16539dc725c60ef4ff4680f8353507":[5,0,0,16,0],
 "classcl_1_1_image2_d_array.html#a8c16539dc725c60ef4ff4680f8353507":[4,0,0,14,0],
-"classcl_1_1_image2_d_g_l.html":[5,0,0,17],
 "classcl_1_1_image2_d_g_l.html":[4,0,0,15],
+"classcl_1_1_image2_d_g_l.html":[5,0,0,17],
 "classcl_1_1_image2_d_g_l.html#a0232c815761105f1c87e833a193b5bcc":[4,0,0,15,1],
 "classcl_1_1_image2_d_g_l.html#a0232c815761105f1c87e833a193b5bcc":[5,0,0,17,1],
 "classcl_1_1_image2_d_g_l.html#a621cec89650cdafd0098bba33c123e20":[5,0,0,17,0],
 "classcl_1_1_image2_d_g_l.html#a621cec89650cdafd0098bba33c123e20":[4,0,0,15,0],
-"classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4":[5,0,0,17,2],
 "classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4":[4,0,0,15,2],
-"classcl_1_1_image2_d_g_l.html#afa612ad692338b92c9c2298a18bc51ab":[4,0,0,15,3],
+"classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4":[5,0,0,17,2],
 "classcl_1_1_image2_d_g_l.html#afa612ad692338b92c9c2298a18bc51ab":[5,0,0,17,3],
-"classcl_1_1_image3_d.html":[4,0,0,16],
-"classcl_1_1_image3_d.html":[5,0,0,18],
-"classcl_1_1_image3_d.html#a28f004720b4cc85a902d218e3dad680d":[4,0,0,16,2],
-"classcl_1_1_image3_d.html#a28f004720b4cc85a902d218e3dad680d":[5,0,0,18,2],
-"classcl_1_1_image3_d.html#a2dde54746a648b4ff62da9b0cdc927dc":[5,0,0,18,3],
-"classcl_1_1_image3_d.html#a2dde54746a648b4ff62da9b0cdc927dc":[4,0,0,16,3],
-"classcl_1_1_image3_d.html#a9243ebeec223f4c6b9681e58b8844214":[4,0,0,16,1],
-"classcl_1_1_image3_d.html#a9243ebeec223f4c6b9681e58b8844214":[5,0,0,18,1],
-"classcl_1_1_image3_d.html#acef8d3ef6b694fcec7934eb21776c1ea":[4,0,0,16,0],
-"classcl_1_1_image3_d.html#acef8d3ef6b694fcec7934eb21776c1ea":[5,0,0,18,0],
-"classcl_1_1_image3_d_g_l.html":[5,0,0,19],
-"classcl_1_1_image3_d_g_l.html":[4,0,0,17],
-"classcl_1_1_image3_d_g_l.html#a21a8fd551430095711413e831cd42ddd":[4,0,0,17,1]
+"classcl_1_1_image2_d_g_l.html#afa612ad692338b92c9c2298a18bc51ab":[4,0,0,15,3],
+"classcl_1_1_image3_d.html":[4,0,0,16]
 };
